NavigationController class

Constructors

Properties

globalConfig GlobalConfig
final
hashCode int
The hash code for this object.
no setterinherited
isNavExpanded ↔ RxBool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

findNavigationRailController() NavigationController
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toggleNavigationRail() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited