responsiveLayout property
Enables automatic responsive behavior: switches between rail and drawer based on screen size.
Implementation
final bool responsiveLayout;
Enables automatic responsive behavior: switches between rail and drawer based on screen size.
final bool responsiveLayout;