NavigationRailPlusDestination class

Represents a single destination item in the custom navigation rail.

Each destination defines an icon, optional selected icon, label, and an optional disabled state to control interaction.

Constructors

Creates a navigation rail destination item.
const

Properties

disabled bool
Whether this destination is interactive.
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
Default icon shown when the item is not selected.
final
label String
Text label displayed next to the icon in expanded mode.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIcon IconData?
Icon shown when the item is selected.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited