disabled property
Whether this destination is interactive.
If true, the item is visually disabled and cannot be selected.
Implementation
final bool disabled;
Whether this destination is interactive.
If true, the item is visually disabled and cannot be selected.
final bool disabled;