resizeToAvoidBottomInset property
If resizeToAvoidBottomInset = false then the body is not resized when the onscreen keyboard appears,
Implementation
final bool resizeToAvoidBottomInset;
If resizeToAvoidBottomInset = false then the body is not resized when the onscreen keyboard appears,
final bool resizeToAvoidBottomInset;