appTheme property
ThemeData
get
appTheme
An extension on BuildContext that provides quick access to commonly used theme properties such as TextTheme and ColorScheme.
This helps reduce boilerplate by allowing you to write:
context.textTheme.bodyLarge
context.colorScheme.primary
Implementation
ThemeData get appTheme => Theme.of(this);