NavigationRailPlus class

Inheritance

Constructors

const

Properties

appBar PreferredSizeWidget?
Fully custom AppBar
final
appBarActions List<Widget>?
Right-side action buttons
final
appBarBackButton Widget?
Custom back button widget
final
appBarBackButtonColor Color?
Color for back button icon
final
appBarBackButtonTap VoidCallback?
Back button callback
final
appBarBackgroundColor Color?
Note: To use appBarBackgroundColor, set appBarForceMaterialTransparency = false
final
appBarBottomDivider bool?
Show divider under AppBar
final
appBarBottomLoading bool?
Show a loading indicator at AppBar bottom
final
appBarBottomRxLoading → RxBool?
Reactive loading indicator for AppBar bottom
final
appBarCenterTitle bool
final
appBarForceMaterialTransparency bool?
Force Material 3 transparency behavior
final
appBarMaxWidth double?
final
appBarText String?
Title text
final
appBarTextStyle TextStyle?
Title style
final
appBarTitleSpacing double?
Space between title appbar and back button
final
backgroundColor Color?
Scaffold background
final
bodyMaxWidth double?
Builders for handling dynamic UI states Main content
final
bottomNavigationBar Widget?
Scaffold bottomNavigationBar
final
bottomSheet Widget?
BottomSheet related properties Custom bottom sheet widget
final
bottomSheetBackgroundColor Color?
Bottom sheet background color
final
bottomSheetLoadingBuilder Widget Function(BuildContext context)?
Bottom sheet loader
final
bottomSheetMaxWidth double?
final
bottomSheetNeedFullWidth bool
If you need width of screen bottom sheet;
final
bottomSheetPaddingBottom double?
Padding for bottom sheet
final
canPop bool
Callback when user tries to pop (back navigation). Return true to allow pop, false to prevent.
final
endDrawerContent Widget?
final
extendBodyBehindAppBar bool
Allow content behind AppBar (e.g. transparent AppBar)
final
externalScaffoldKey GlobalKey<ScaffoldState>?
final
floatingActionButton Widget?
Floating Action Button
final
floatingActionButtonLocation FloatingActionButtonLocation?
final
hashCode int
The hash code for this object.
no setterinherited
isDrawerSafeAreaBottom bool
Drawer safe area bottom
final
isDrawerSafeAreaTop bool
Drawer safe area top
final
isEndDrawerSafeAreaBottom bool
End Drawer safe area bottom
final
isEndDrawerSafeAreaTop bool
End Drawer safe area top
final
isSafeAreaBottom bool
Apply SafeArea padding at bottom
final
isSafeAreaTop bool
SafeArea related properties Apply SafeArea padding at top
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
final
final
Navigatio header config
final
Navigation leading config
final
Additional widgets rendered between navigation items and footer. Only visible in expanded state.
final
needOverlayStyle bool
Whether to apply system overlay style (status bar)
final
onDestinationSelected ValueChanged<int>?
Callback triggered when a navigation item is selected. Returns the selected index.
final
onPopInvokedWithResult → void Function(bool didPop, Object? result)?
final
onRefresh Function?
Pull-to-refresh callback
final
padding EdgeInsetsGeometry?
Body padding
final
resizeToAvoidBottomInset bool
If resizeToAvoidBottomInset = false then the body is not resized when the onscreen keyboard appears,
final
responsiveBody Widget?
Main content widget used in responsive layouts. Displayed alongside rail or inside scaffold body.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIndex int?
Index of the currently selected navigation destination.
final
underneathBackgroundColor Color?
Below Scaffold background
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<NavigationRailPlus>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited